@@ -209,11 +209,11 @@ GstUri * gst_uri_from_string_with_base (GstUri * base,
 gboolean gst_uri_equal                 (const GstUri * first,
                                         const GstUri * second);
 GstUri * gst_uri_join                  (GstUri * base_uri,
-                                        GstUri * ref_uri);
+                                        GstUri * ref_uri) G_GNUC_WARN_UNUSED_RESULT;
 gchar *  gst_uri_join_strings          (const gchar * base_uri,
                                         const gchar * ref_uri) G_GNUC_MALLOC;
 gboolean gst_uri_is_writable           (const GstUri * uri);
-GstUri * gst_uri_make_writable         (GstUri * uri);
+GstUri * gst_uri_make_writable         (GstUri * uri) G_GNUC_WARN_UNUSED_RESULT;
 gchar *  gst_uri_to_string             (const GstUri * uri) G_GNUC_MALLOC;
 gboolean gst_uri_is_normalized         (const GstUri * uri);
 gboolean gst_uri_normalize             (GstUri * uri);
@@ -250,6 +250,7 @@ const gchar * gst_uri_get_query_value  (const GstUri * uri,
 GList * gst_uri_get_query_keys         (const GstUri * uri);
 const gchar * gst_uri_get_fragment     (const GstUri * uri);
 gboolean gst_uri_set_fragment          (GstUri * uri, const gchar * fragment);
+GHashTable * gst_uri_get_media_fragment_table  (const GstUri * uri);
 
 /**
  * gst_uri_copy:
@@ -261,10 +262,6 @@ gboolean gst_uri_set_fragment          (GstUri * uri, const gchar * fragment);
  * Returns: (transfer full): A new #GstUri object which is a copy of this
  *          #GstUri or %NULL.
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC GstUri * gst_uri_copy (const GstUri * uri);
-#endif
-
 static inline GstUri *
 gst_uri_copy (const GstUri * uri)
 {
@@ -280,10 +277,6 @@ gst_uri_copy (const GstUri * uri)
  *
  * Returns: This object with the reference count incremented.
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC GstUri * gst_uri_ref (GstUri * uri);
-#endif
-
 static inline GstUri *
 gst_uri_ref (GstUri * uri)
 {
@@ -300,16 +293,16 @@ gst_uri_ref (GstUri * uri)
  *
  * See gst_mini_object_unref() for further info.
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC void gst_uri_unref (GstUri * uri);
-#endif
-
 static inline void
 gst_uri_unref (GstUri * uri)
 {
   gst_mini_object_unref (GST_MINI_OBJECT_CAST (uri));
 }
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstUri, gst_uri_unref)
+#endif
+
 G_END_DECLS
 
 #endif /* __GST_URI_H__ */
