@@ -59,6 +59,7 @@ enum
 };
 
 #define DEFAULT_SYNC FALSE
+#define DEFAULT_DROP_OUT_OF_SEGMENT TRUE
 
 #define DEFAULT_STATE_ERROR FAKE_SINK_STATE_ERROR_NONE
 #define DEFAULT_SILENT TRUE
@@ -76,6 +77,7 @@ enum
   PROP_SILENT,
   PROP_DUMP,
   PROP_SIGNAL_HANDOFFS,
+  PROP_DROP_OUT_OF_SEGMENT,
   PROP_LAST_MESSAGE,
   PROP_CAN_ACTIVATE_PUSH,
   PROP_CAN_ACTIVATE_PULL,
@@ -165,6 +167,12 @@ gst_fake_sink_class_init (GstFakeSinkClass * klass)
       g_param_spec_boolean ("signal-handoffs", "Signal handoffs",
           "Send a signal before unreffing the buffer", DEFAULT_SIGNAL_HANDOFFS,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+  g_object_class_install_property (gobject_class, PROP_DROP_OUT_OF_SEGMENT,
+      g_param_spec_boolean ("drop-out-of-segment",
+          "Drop out-of-segment buffers",
+          "Drop and don't render / hand off out-of-segment buffers",
+          DEFAULT_DROP_OUT_OF_SEGMENT,
+          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gobject_class, PROP_SILENT,
       g_param_spec_boolean ("silent", "Silent",
           "Don't produce last_message events", DEFAULT_SILENT,
@@ -172,15 +180,14 @@ gst_fake_sink_class_init (GstFakeSinkClass * klass)
           G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gobject_class, PROP_DUMP,
       g_param_spec_boolean ("dump", "Dump", "Dump buffer contents to stdout",
-          DEFAULT_DUMP, G_PARAM_READWRITE | GST_PARAM_MUTABLE_PLAYING |
+          DEFAULT_DUMP,
+          G_PARAM_READWRITE | GST_PARAM_MUTABLE_PLAYING |
           G_PARAM_STATIC_STRINGS));
-  g_object_class_install_property (gobject_class,
-      PROP_CAN_ACTIVATE_PUSH,
+  g_object_class_install_property (gobject_class, PROP_CAN_ACTIVATE_PUSH,
       g_param_spec_boolean ("can-activate-push", "Can activate push",
           "Can activate in push mode", DEFAULT_CAN_ACTIVATE_PUSH,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-  g_object_class_install_property (gobject_class,
-      PROP_CAN_ACTIVATE_PULL,
+  g_object_class_install_property (gobject_class, PROP_CAN_ACTIVATE_PULL,
       g_param_spec_boolean ("can-activate-pull", "Can activate pull",
           "Can activate in pull mode", DEFAULT_CAN_ACTIVATE_PULL,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
@@ -224,8 +231,8 @@ gst_fake_sink_class_init (GstFakeSinkClass * klass)
       "Erik Walthinsen <omega@cse.ogi.edu>, "
       "Wim Taymans <wim@fluendo.com>, "
       "Mr. 'frag-me-more' Vanderwingo <wingo@fluendo.com>");
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&sinktemplate));
+
+  gst_element_class_add_static_pad_template (gstelement_class, &sinktemplate);
 
   gstelement_class->change_state =
       GST_DEBUG_FUNCPTR (gst_fake_sink_change_state);
@@ -247,6 +254,8 @@ gst_fake_sink_init (GstFakeSink * fakesink)
   fakesink->num_buffers = DEFAULT_NUM_BUFFERS;
 
   gst_base_sink_set_sync (GST_BASE_SINK (fakesink), DEFAULT_SYNC);
+  gst_base_sink_set_drop_out_of_segment (GST_BASE_SINK (fakesink),
+      DEFAULT_DROP_OUT_OF_SEGMENT);
 }
 
 static void
@@ -276,6 +285,10 @@ gst_fake_sink_set_property (GObject * object, guint prop_id,
     case PROP_SIGNAL_HANDOFFS:
       sink->signal_handoffs = g_value_get_boolean (value);
       break;
+    case PROP_DROP_OUT_OF_SEGMENT:
+      gst_base_sink_set_drop_out_of_segment (GST_BASE_SINK (object),
+          g_value_get_boolean (value));
+      break;
     case PROP_CAN_ACTIVATE_PUSH:
       GST_BASE_SINK (sink)->can_activate_push = g_value_get_boolean (value);
       break;
@@ -312,6 +325,10 @@ gst_fake_sink_get_property (GObject * object, guint prop_id, GValue * value,
     case PROP_SIGNAL_HANDOFFS:
       g_value_set_boolean (value, sink->signal_handoffs);
       break;
+    case PROP_DROP_OUT_OF_SEGMENT:
+      g_value_set_boolean (value,
+          gst_base_sink_get_drop_out_of_segment (GST_BASE_SINK (object)));
+      break;
     case PROP_LAST_MESSAGE:
       GST_OBJECT_LOCK (sink);
       g_value_set_string (value, sink->last_message);
@@ -431,7 +448,7 @@ gst_fake_sink_render (GstBaseSink * bsink, GstBuffer * buf)
 
   if (!sink->silent) {
     gchar dts_str[64], pts_str[64], dur_str[64];
-    gchar *flag_str;
+    gchar *flag_str, *meta_str;
 
     GST_OBJECT_LOCK (sink);
     g_free (sink->last_message);
@@ -458,16 +475,19 @@ gst_fake_sink_render (GstBaseSink * bsink, GstBuffer * buf)
     }
 
     flag_str = gst_buffer_get_flags_string (buf);
+    meta_str = gst_buffer_get_meta_string (buf);
 
     sink->last_message =
         g_strdup_printf ("chain   ******* (%s:%s) (%u bytes, dts: %s, pts: %s"
         ", duration: %s, offset: %" G_GINT64_FORMAT ", offset_end: %"
-        G_GINT64_FORMAT ", flags: %08x %s) %p",
+        G_GINT64_FORMAT ", flags: %08x %s, meta: %s) %p",
         GST_DEBUG_PAD_NAME (GST_BASE_SINK_CAST (sink)->sinkpad),
         (guint) gst_buffer_get_size (buf), dts_str, pts_str,
         dur_str, GST_BUFFER_OFFSET (buf), GST_BUFFER_OFFSET_END (buf),
-        GST_MINI_OBJECT_CAST (buf)->flags, flag_str, buf);
+        GST_MINI_OBJECT_CAST (buf)->flags, flag_str,
+        meta_str ? meta_str : "none", buf);
     g_free (flag_str);
+    g_free (meta_str);
     GST_OBJECT_UNLOCK (sink);
 
     gst_fake_sink_notify_last_message (sink);
@@ -479,9 +499,10 @@ gst_fake_sink_render (GstBaseSink * bsink, GstBuffer * buf)
   if (sink->dump) {
     GstMapInfo info;
 
-    gst_buffer_map (buf, &info, GST_MAP_READ);
-    gst_util_dump_mem (info.data, info.size);
-    gst_buffer_unmap (buf, &info);
+    if (gst_buffer_map (buf, &info, GST_MAP_READ)) {
+      gst_util_dump_mem (info.data, info.size);
+      gst_buffer_unmap (buf, &info);
+    }
   }
   if (sink->num_buffers_left == 0)
     goto eos;
